@@ -18,6 +18,8 @@
 #'  in NetCDFv3 format (numeric). Default output is NetCDFv4.
 #'@param overwrite logical; should existing output file be overwritten?
 #'@param verbose logical; if TRUE, progress messages are shown
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'
 #'@return A NetCDF file including a time series of monthly means is written.
 #'@export
@@ -61,6 +63,6 @@
 #'
 #'unlink(c(file.path(tempdir(),"CMSAF_example_file.nc"), 
 #'  file.path(tempdir(),"CMSAF_example_file_monmean.nc")))
-monmean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE) {
-  monx_wrapper(3, var, infile, outfile, nc34, overwrite, verbose)
+monmean <- function(var, infile, outfile, nc34 = 4, overwrite = FALSE, verbose = FALSE, nc = NULL) {
+  monx_wrapper(3, var, infile, outfile, nc34, overwrite, verbose, nc = nc)
 }
