@@ -5,9 +5,12 @@
 #'@param infile Filename of input NetCDF file. This may include the directory 
 #' (character).
 #'@param var_name Name of NetCDF variable (character).
+#'@param nc Alternatively to \code{infile} you can specify the input as an
+#'  object of class `ncdf4` (as returned from \code{ncdf4::nc_open}).
 #'@export
-read_file <- function(infile, var_name) {
-  id <- nc_open(infile)
+read_file <- function(infile, var_name, nc = NULL) {
+  if (!is.null(nc)) id <- nc
+  else id <- nc_open(infile)
 
   global_att <- ncatt_get(id, 0)
 
@@ -65,7 +68,7 @@ read_file <- function(infile, var_name) {
     t = ncvar_get(id, dimensions$names$t)
 
   )
-  nc_close(id)
+  if (is.null(nc)) nc_close(id)
 
   result <- list(
     global_att = global_att,
